aboutsummaryrefslogtreecommitdiffstats
path: root/xen/include/xen/event.h
diff options
context:
space:
mode:
authorkaf24@firebug.cl.cam.ac.uk <kaf24@firebug.cl.cam.ac.uk>2005-05-12 13:58:47 +0000
committerkaf24@firebug.cl.cam.ac.uk <kaf24@firebug.cl.cam.ac.uk>2005-05-12 13:58:47 +0000
commit3b2bf5dfb1110ffb1a5fb7a3d02b66315f9c552d (patch)
tree74b075e518f21996d1c2583b1d885da694fc9900 /xen/include/xen/event.h
parenta6ba03510e86c088ef940c521781223c8dc2fc0d (diff)
downloadxen-3b2bf5dfb1110ffb1a5fb7a3d02b66315f9c552d.tar.gz
xen-3b2bf5dfb1110ffb1a5fb7a3d02b66315f9c552d.tar.bz2
xen-3b2bf5dfb1110ffb1a5fb7a3d02b66315f9c552d.zip
bitkeeper revision 1.1389.20.1 (42836117f2yEkILParltXJcom3kTeA)
More descriptive 'flags' and 'id' field names for exec_domain/domain structures seems a good idea after all. At the same time, I've renamed the flag macros to be a bit neater and more descriptive, and more in keeping with the style of such definitions in asm/mm.h, for example. Signed-off-by: Keir Fraser <keir@xensource.com>
Diffstat (limited to 'xen/include/xen/event.h')
-rw-r--r--xen/include/xen/event.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/xen/include/xen/event.h b/xen/include/xen/event.h
index ac7ce6b1a0..306883c594 100644
--- a/xen/include/xen/event.h
+++ b/xen/include/xen/event.h
@@ -35,15 +35,15 @@ static inline void evtchn_set_pending(struct exec_domain *ed, int port)
set_bit(0, &ed->vcpu_info->evtchn_upcall_pending);
/*
* NB1. 'flags' and 'processor' must be checked /after/ update of
* pending flag. These values may fluctuate (after all, we hold no
* locks) but the key insight is that each change will cause
* evtchn_upcall_pending to be polled.
*
* NB2. We save DF_RUNNING across the unblock to avoid a needless
* IPI for domains that we IPI'd to unblock.
*/
- running = test_bit(EDF_RUNNING, &ed->flags);
+ running = test_bit(_VCPUF_running, &ed->vcpu_flags);
exec_domain_unblock(ed);
if ( running )
smp_send_event_check_cpu(ed->processor);
@@ -35,15 +35,15 @@ static inline void evtchn_set_pending(struct exec_domain *ed, int port)
set_bit(0, &ed->vcpu_info->evtchn_upcall_pending);
/*
- * NB1. 'flags' and 'processor' must be checked /after/ update of
+ * NB1. 'vcpu_flags' and 'processor' must be checked /after/ update of
* pending flag. These values may fluctuate (after all, we hold no
* locks) but the key insight is that each change will cause
@@ -35,15 +35,15 @@ static inline void evtchn_set_pending(struct exec_domain *ed, int port)
* evtchn_upcall_pending to be polled.
*
- * NB2. We save DF_RUNNING across the unblock to avoid a needless
+ * NB2. We save VCPUF_running across the unblock to avoid a needless
* IPI for domains that we IPI'd to unblock.
*/